/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/
package org.apache.cayenne.di;

import java.util.Map;

/**
 * A binding builder for map configurations. Creates a parameterized map of type &lt;String, T&gt;.
 * 
 * @param <T> A type of the map values.
 * @since 3.1
 */
public interface MapBuilder<T> {

    MapBuilder<T> put(String key, Class<? extends T> interfaceType) throws DIRuntimeException;

    MapBuilder<T> put(String key, T value) throws DIRuntimeException;

    MapBuilder<T> putAll(Map<String, T> map) throws DIRuntimeException;

    void in(Scope scope);

    /**
     * @since 4.1
     */
    void withoutScope();
}
